import assert from "assert"

import {
    EncodeVersion,
    DecodeVersion,
    FormatVersion
} from "../ts/lib/util/Version"

describe("EncodeVersion", () => {
    it("Should encode a version from a year, month, day, revision to an integer.", () => {
        assert.strictEqual(EncodeVersion(2020, 9, 9, 0), 50516650);
        assert.strictEqual(EncodeVersion(2018, 1, 2, 1), 50451901);
        assert.strictEqual(EncodeVersion(2020, 11, 17, 0), 50520650);
    });
});

describe("DecodeVersion", () => {
    it("Should decode a version integer into a year, month, day and revision.", () => {
        assert.deepStrictEqual(DecodeVersion(50516750), { year: 2020, month: 9, day: 11, revision: 0 });
        assert.deepStrictEqual(DecodeVersion(50520350), { year: 2020, month: 11, day: 11, revision: 0 });
        assert.deepStrictEqual(DecodeVersion(50520650), { year: 2020, month: 11, day: 17, revision: 0 });
    });
});

describe("FormatVersion", () => {
    it("Should format version information into a string.", () => {
        assert.strictEqual(FormatVersion(2020, 9, 11, 0), "2020.9.11.0");
        assert.strictEqual(FormatVersion(2020, 11, 11, 0), "2020.11.11.0");
        assert.strictEqual(FormatVersion(2020, 17, 11, 0), "2020.17.11.0");
    });
});